@@ -203,8 +203,11 @@ class binary_eda_plot:
         
         f = self.data.groupby(col)[self.target].mean()
         f.name = 'target_rate'
+
+        g = a/len(self.data)
+        g.name = 'attr_rate'
         
-        results = pd.concat([a, b, c, d, e, f], axis=1)
+        results = pd.concat([a, b, c, d, e, f, g], axis=1)
         
         results.index = results.index.map(str)
         
@@ -221,6 +224,8 @@ class binary_eda_plot:
         ax2.plot(results['distr_bads'], marker='o', color='black', label='non-event_rate')
         
         ax2.plot(results['target_rate'], marker='o', color='red', label='target_rate')
+
+        ax2.plot(results['attr_rate'], marker='o', color='#00FF00', label='attr_rate')
         
         ax2.set_yticklabels(['{:.0%}'.format(x) for x in ax2.get_yticks()])
         
